pub enum MySqlTimeError {
FieldRange {
field: &'static str,
max: u32,
value: u64,
},
SubsecondExcess {
sign: MySqlTimeSign,
microseconds: u32,
truncated: MySqlTime,
},
NegativeZero,
}Expand description
Errors returned by MySqlTime::new().
Variants
FieldRange
A field of MySqlTime exceeded its max range.
SubsecondExcess
Error returned for time magnitudes (positive or negative) between 838:59:59.0 and 839:00:00.0.
Other range errors should be covered by Self::FieldRange for the hours field.
For applications which can tolerate rounding, a valid truncated value is provided.
Fields

sign: MySqlTimeSignThe sign of the magnitude.

truncated: MySqlTimeThe truncated value,
either MySqlTime::MIN if negative or MySqlTime::MAX if positive.
NegativeZero
MySQL coerces -00:00:00 to 00:00:00 but this API considers that an error.
For applications which can tolerate coercion, you can convert this error to MySqlTime::ZERO.